@@ -13,6 +13,7 @@ __all__ = [
     "expand_dataframe_column",
     "concat_pages_to_dataframe",
     "Duration",
+    "join_list_query_param"
 ]
 
 
@@ -155,3 +156,10 @@ def concat_pages_to_dataframe(
 
     # Concat dataframes
     return df
+
+
+def join_list_query_param(param: Optional[Union[str, List[str]]]):
+    if param is None or isinstance(param, str):
+        return param
+    else:
+        return ",".join(param)
