@@ -2,6 +2,8 @@ from typing import Optional, Union, List
 from datetime import datetime, timedelta, timezone
 import dateutil
 
+import pandas as pd
+
 from .. import _dtos
 from ... import api
 
@@ -163,11 +165,13 @@ class TestModelExecution(_dtos.ModelExecution):
     def add_duration_input(
         self,
         source_code_name: str = "duration_input",
-        value: Optional[int] = 86_400_000,
+        iso_duration: Optional[str] = "PT12H",
     ):
         self.pythonModelInstance.inputParameters.append(
             _dtos.DurationParameter(
-                type="DURATION", sourceCodeName=source_code_name, value=value
+                type="DURATION",
+                sourceCodeName=source_code_name,
+                value=int(pd.Timedelta(iso_duration).total_seconds() * 1000),
             )
         )
 
